
# Slot: typeof


Names a parent type

URI: [linkml:typeof](https://w3id.org/linkml/typeof)


## Domain and Range

[TypeDefinition](TypeDefinition.md) &#8594;  <sub>0..1</sub> [TypeDefinition](TypeDefinition.md)

## Parents


## Children


## Used by

 * [TypeDefinition](TypeDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Comments:** | | the target type definition of the typeof slot is referred to as the "parent type" |
|  | | the type definition containing the typeof slot is referred to as the "child type" |
|  | | type definitions without a typeof slot are referred to as a "root type" |

